package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcTbcz;
import com.ruoyi.tcZz.domain.TcTbwc;
import com.ruoyi.tcZz.service.ITcTbwcService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 通报完成情况Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "通报完成情况")
@RequestMapping("/tcZz/networkSecurity/tbwc")
public class TcTbwcController extends BaseController {
    @Autowired
    private ITcTbwcService tcTbwcService;

    /**
     * 查询通报完成情况列表
     */
    @ApiOperation(value = "查询通报完成情况列表", response = TcTbwc.class)
    @GetMapping("/list")
    public TableDataInfo list(TcTbwc tcTbwc) {
        startPage();
        List<TcTbwc> list = tcTbwcService.selectTcTbwcList(tcTbwc);
        return getDataTable(list);
    }

    /**
     * 导出通报完成情况列表
     */
    @ApiOperation(value = "导出通报完成情况列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcTbwc tcTbwc) {
        List<TcTbwc> list = tcTbwcService.selectTcTbwcList(tcTbwc);
        ExcelUtil<TcTbwc> util = new ExcelUtil<TcTbwc>(TcTbwc.class);
        util.exportExcel(response, list, "通报完成情况数据");
    }

    /**
     * 获取通报完成情况详细信息
     */
    @ApiOperation(value = "获取通报完成情况详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcTbwcService.selectTcTbwcById(id));
    }

    /**
     * 新增通报完成情况
     */
    @ApiOperation(value = "新增通报完成情况")
    @PostMapping
    public AjaxResult add(@RequestBody TcTbwc tcTbwc) {
        return toAjax(tcTbwcService.insertTcTbwc(tcTbwc));
    }

    /**
     * 修改通报完成情况
     */
    @ApiOperation(value = "修改通报完成情况")
    @PutMapping
    public AjaxResult edit(@RequestBody TcTbwc tcTbwc) {
        return toAjax(tcTbwcService.updateTcTbwc(tcTbwc));
    }

    /**
     * 删除通报完成情况
     */
    @ApiOperation(value = "删除通报完成情况")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcTbwcService.deleteTcTbwcByIds(ids));
    }




    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcTbwc> util = new ExcelUtil<TcTbwc>(TcTbwc.class);
        List<TcTbwc> tcTbwcList = util.importExcel(file.getInputStream());
        tcTbwcService.importUser(tcTbwcList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcTbwcService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcTbwc> util = new ExcelUtil<TcTbwc>(TcTbwc.class);
        util.importTemplateExcel(response, " 通报完成情况");
    }
}
